@@ -1,6 +1,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
+#include <unistd.h>
 
 #include "vt.h"
 #include "misc.h"
@@ -197,7 +198,6 @@ main(int argc, char **argv)
     char *fname = "ttext-%s.%e";
     char *out_fmt = "ascii";
     struct export *fmt = 0;
-    int pgno, subno;
     int opt, ind;
     char *arg;
     struct vbi *vbi;
