@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <sys/time.h>
+#include <time.h>	/* to keep glibc 2.2 quiet */
 #include <stdlib.h>
 #include <unistd.h>
 #include <signal.h>
@@ -46,7 +47,7 @@ chk_time(int t)
 	dt += 24*60*60;
 
     if (dt <= -max_diff || dt >= max_diff)
-	fatal("time diff to big (%2d:%02d:%02d)", dt/60/60, abs(dt)/60%60, abs(dt)%60);
+	fatal("time diff too big (%2d:%02d:%02d)", dt/60/60, abs(dt)/60%60, abs(dt)%60);
 
     sys_t += dt;
 
