@@ -214,7 +214,7 @@ if (!D->bare)
 	      {
 		if (last_space)
 		  {
-		    fprintf(fp,"&nbsp;");
+		    fprintf(fp,"&nbsp");
 		    last_space=0;
 		    nbsp=1;
 		  }
@@ -251,7 +251,7 @@ if (!D->bare)
 		      {
 			if (last_space)
 			  {
-			    fprintf(fp,"&nbsp;");
+			    fprintf(fp,"&nbsp");
 			    last_space=0;
 			    nbsp=1;
 			  }
