@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <string.h>
+#include <stdlib.h>
 #include "os.h"
 #include "export.h"
 
@@ -13,6 +14,7 @@ static char *txt_opts[] =	// module options
     "gfx-chr=<char>",		// substitute <char> for gfx-symbols
     "fg=<0-7|none>",		// assume term has <x> as foreground color
     "bg=<0-7|none>",		// assume term has <x> as background color
+    "lines=<1-25>",		// output 24 or 25 lines
     0
 };
 
@@ -22,6 +24,7 @@ struct txt_data			// private data in struct export
     u8 gfx_chr;
     u8 def_fg;
     u8 def_bg;
+    int endline;
     struct fmt_char curr[1];
     FILE *fp;
 };
@@ -55,15 +58,14 @@ struct export_module export_ansi[1] =	// exported module definition
 #define D  ((struct txt_data *)e->data)
 
 
-#ifdef BSD
+
 char *
-stpcpy(char *dst, const char *src)
+my_stpcpy(char *dst, const char *src) /* glibc bastards :-( */
 {
     while (*dst = *src++)
 	dst++;
     return dst;
 }
-#endif
 
 
 static int
@@ -72,6 +74,7 @@ txt_open(struct export *e)
     D->gfx_chr = '#';
     D->def_fg = -1;
     D->def_bg = -1;
+    D->endline = H;
     if (e->mod == export_ansi)
 	D->color = 1;
     return 0;
@@ -94,6 +97,13 @@ txt_option(struct export *e, int opt, char *arg)
 	case 4: // bg=
 	    D->def_bg = *arg - '0';
 	    break;
+	case 5: // lines=
+	    D->endline = atoi(arg);
+	    if (D->endline < 1 || D->endline > H)
+	    {
+		export_error("lines: invalid number");
+		return 1;
+	    }
     }
     return 0;
 }
@@ -122,18 +132,18 @@ put_attr(struct export *e, struct fmt_char *new)
 	    if (bg && new->bg == D->def_bg)	// switch to def bg -> reset all
 		reset = 1;
 
-	    p = stpcpy(buf, "\e[");
+	    p = my_stpcpy(buf, "\e[");
 	    if (reset)
 	    {
-		p = stpcpy(p, ";");		// "0;" but 0 isn't neccesary
+		p = my_stpcpy(p, ";");		// "0;" but 0 isn't neccesary
 		attr = -1;			// set all attributes
 		fg = new->fg ^ D->def_fg;	// set fg if != default fg
 		bg = new->bg ^ D->def_bg;	// set bg if != default bg
 	    }
 	    if (attr & new->attr & EA_BLINK)
-		p = stpcpy(p, "5;");			// blink
+		p = my_stpcpy(p, "5;");			// blink
 	    if (attr & new->attr & EA_DOUBLE)
-		p = stpcpy(p, "1;");			// bold
+		p = my_stpcpy(p, "1;");			// bold
 	    if (fg)
 		p += sprintf(p, "%d;", new->fg + 30);	// fg-color
 	    if (bg)
@@ -154,9 +164,7 @@ txt_output(struct export *e, char *name, struct fmt_page *pg)
     struct fmt_char def_c[1];
     struct fmt_char l[W+2];
     #define L (l+1)
-    FILE *fp;
     int x, y;
-    int x2, x3;
 
     D->fp = fopen(name, "w");
     if (not D->fp)
@@ -173,7 +181,7 @@ txt_output(struct export *e, char *name, struct fmt_page *pg)
     *D->curr = *def_c;
     L[-1] = L[W] = *def_c;
 
-    for (y = 0; y < H; y++)
+    for (y = 0; y < D->endline; y++)
 	if (~pg->hid & (1 << y))	// not hidden
 	{
 	    // character conversion
