@@ -246,7 +246,7 @@ fmt_page(struct export *e, struct fmt_page *pg, struct vt_page *vtp)
 {
     char buf[16];
     int x, y;
-    u8 c, *p = vtp->data[0];
+    u8 *p = vtp->data[0];
 
     pg->dbl = 0;
 
@@ -286,8 +286,11 @@ fmt_page(struct export *e, struct fmt_page *pg, struct vt_page *vtp)
 		    c.attr &= EA_DOUBLE;
 		    goto ctrl;
 		case 0x0d:		/* double height */
-		    c.attr |= EA_DOUBLE;
-		    dbl = 1;
+		    if (y < H-2)	/* ignored on last 2 lines */
+		    {
+			c.attr |= EA_DOUBLE;
+			dbl = 1;
+		    }
 		    goto ctrl;
 		case 0x10 ... 0x17:	/* gfx + fg color */
 		    c.fg = c.ch & 7;
