@@ -170,16 +170,16 @@ do_next_pgno(struct vtwin *w, int dir, int bcd_mode, int subs, int new_win)
 #define notdigit(x) (not isdigit((x)))
 
 static int
-chk_screen_subno(u8 *p, int x, int *n1, int *n2)
+chk_screen_fromto(u8 *p, int x, int *n1, int *n2)
 {
     p += x;
 
-    if (x >= 0 && x < 42-5)
+    if (x >= 0 && x+5 < 42)
 	if (notdigit(p[1]) || notdigit(p[0]))
 	    if (isdigit(p[2]))
 		if (p[3] == '/' || p[3] == ':')
 		    if (isdigit(p[4]))
-			if (notdigit(p[5]) || notdigit(p[6]))
+			if (notdigit(p[5]) || notdigit(p[6]))	/* p[6] is save here */
 			{
 			    *n1 = p[2] % 16;
 			    if (isdigit(p[1]))
@@ -197,23 +197,30 @@ chk_screen_pgno(u8 *p, int x, int *pgno, int *subno)
 {
     p += x;
 
-    if (x >= 0 && x < 42-4)
+    if (x >= 0 && x+4 < 42)
 	if (notdigit(p[0]) && notdigit(p[4]))
-	    if (isdigit(p[1]))
-		if (isdigit(p[2]))
-		    if (isdigit(p[3]))
-		    {
-			*pgno = p[1] % 16 * 256 + p[2] % 16 * 16 + p[3] % 16;
-			if (*pgno >= 0x100 && *pgno <= 0x999)
-			{
-			    *subno = ANY_SUB;
-			    // hackhackhack:
-			    // pgno followed by start box gets subno 1
-			    if (x+4 < 40 && p[4] == 11)
-				*subno = 1;
-			    return 1;
-			}
-		    }
+	    if (isdigit(p[1]) && isdigit(p[2]) && isdigit(p[3]))
+	    {
+		*pgno = p[1] % 16 * 256 + p[2] % 16 * 16 + p[3] % 16;
+		if (*pgno >= 0x100 && *pgno <= 0x999)
+		{
+		    *subno = ANY_SUB;
+		    if (x+6 < 42)
+			if (p[4] == '.' || p[4] == '/')
+			    if (isdigit(p[5]))
+				if (notdigit(p[6]) || notdigit(p[7]))	/* p[7] is save here */
+				{
+				    *subno = p[5] % 16;
+				    if (isdigit(p[6]))
+					*subno = *subno * 16 + p[6] % 16;
+				}
+		    // hackhackhack:
+		    // pgno followed by start box gets subno 1
+		    if (x+4 < 42 && p[4] == 11)
+			*subno = 1;
+		    return 1;
+		}
+	    }
     return 0;
 }
 
@@ -223,7 +230,7 @@ do_screen_pgno(struct vtwin *w, int x, int y, int new_win)
     u8 buf[42];
     int n1, n2, i;
 
-    if (x >= 0 || x < 40)
+    if (x >= 0 && x < 40)
     {
 	if (xio_get_line(w->xw, y, buf+1) == 0)
 	{
@@ -233,7 +240,7 @@ do_screen_pgno(struct vtwin *w, int x, int y, int new_win)
 	    for (i = -6; i < 35; i++)
 	    {
 		if (w->vtp == 0 || w->vtp->subno != 0)
-		    if (chk_screen_subno(buf, x+i, &n1, &n2))
+		    if (chk_screen_fromto(buf, x+i, &n1, &n2))
 		    {
 			// subno cycling works wrong with children.
 			// so middle button cycles backwards...
