@@ -19,19 +19,23 @@ struct vbi
     int fd;
     struct cache *cache;
     struct dl_head clients[1];
-    int bufsize;		// 32*2k or 38*2k (depending on bttv version)
+    // raw buffer management
+    int bufsize;		// nr of bytes sent by this device
+    int bpl;			// bytes per line
     u32 seq;
+    // page assembly
     struct raw_page rpage[8];	// one for each magazin
     struct raw_page *ppage;	// points to page of previous pkt0
-    /*
-    struct vt_page page[8];	// one for each magazin
-    struct vt_page *ppage;	// points to page of previous pkt0
-    */
+    // phase correction
     int pll_fixed;		// 0 = auto, 1..2*PLL_ADJUST+1 = fixed
     int pll_adj;
     int pll_dir;
     int pll_cnt;
     int pll_err, pll_lerr;
+    // v4l2 decoder data
+    int bpb;			// bytes per bit * 2^16
+    int bp8bl, bp8bh;		// bytes per 8-bit low/high
+    int soc, eoc;		// start/end of clock run-in
 };
 
 struct vbi_client
