@@ -35,7 +35,7 @@ static struct dl_head dpys[1];		/* list of all displays */
 static int
 timer_init(int argc, char **argv)
 {
-    static xio_timer();
+    static void xio_timer();
     int p[2], timer_pid, i;
 
     if (pipe(p) == -1)
@@ -71,7 +71,6 @@ static int
 local_init(int argc, char **argv)
 {
     static int inited = 0;
-    int i;
 
     if (inited)
 	return 0;
